@@ -30,6 +30,7 @@ import socket
 
 from ssl import create_default_context
 import certifi
+from elasticsearch import RequestsHttpConnection
 
 # This comment is necessary because pylint throws errors when using the elasticsearch API because it uses decorators.
 # pylint: disable=E1123
@@ -76,7 +77,9 @@ class Elasticsearchlib:
         _es = Elasticsearch(hosts=[{'host': host, 'port': port}],
                             http_auth=('easier', 'easier-123.'),
                             scheme="https",
-                            ssl_context=ssl_context,
+                            connection_class=RequestsHttpConnection,
+                            use_ssl=True,
+                            #ssl_context=ssl_context,
                             verify_certs=False)
         self.request_retries = request_retries
         self.total_retries = total_retries
